<pre><code>  ____                                        _    ____ _                 _
 |  _ \  ___   ___ _   _ _ __ ___   ___ _ __ | |_ / ___| | ___  _   _  __| |
 | | | |/ _ \ / __| | | | '_ ` _ \ / _ \ '_ \| __| |   | |/ _ \| | | |/ _` |
 | |_| | (_) | (__| |_| | | | | | |  __/ | | | |_| |___| | (_) | |_| | (_| |
 |____/ \___/ \___|\__,_|_| |_| |_|\___|_| |_|\__|\____|_|\___/ \__,_|\__,_|/  </code></pre>

A simple python wrapper for the DocumentCloud API

* Documentation: [http://documentcloud.readthedocs.org/](http://documentcloud.readthedocs.org/)
* Issues: [https://github.com/muckrock/python-documentcloud/issues](https://github.com/muckrock/python-documentcloud/issues)
* Packaging: [https://pypi.python.org/pypi/documentcloud](https://pypi.python.org/pypi/documentcloud)

Features
--------

* Retrieve and edit documents and projects, both public and private, from documentcloud.org
* Upload PDFs into your documentcloud.org account and organize them into projects
* Download text and images extracted from your PDFs by DocumentCloud

Getting started
---------------

Installation is as easy as...

```bash
$ pip install documentcloud
```
